@@ -1,6 +1,8 @@
 from django.db import models
 import pgtrigger
 
+from pghistory import utils
+
 
 def _get_pgh_obj_pk_col(history_model):
     """
@@ -50,6 +52,7 @@ class Event(pgtrigger.Trigger):
             for f in self.event_model._meta.fields
             if not isinstance(f, models.AutoField)
             and hasattr(self.event_model.pgh_tracked_model, f.name)
+            and f.concrete
         }
         fields["pgh_created_at"] = "NOW()"
         fields["pgh_label"] = f"'{self.label}'"
@@ -58,7 +61,24 @@ class Event(pgtrigger.Trigger):
             fields["pgh_obj_id"] = f'{self.snapshot}."{_get_pgh_obj_pk_col(self.event_model)}"'
 
         if hasattr(self.event_model, "pgh_context"):
-            fields["pgh_context_id"] = "_pgh_attach_context()"
+            if isinstance(self.event_model._meta.get_field("pgh_context"), models.ForeignKey):
+                fields["pgh_context_id"] = "_pgh_attach_context()"
+            elif isinstance(self.event_model._meta.get_field("pgh_context"), utils.JSONField):
+                fields["pgh_context"] = (
+                    "COALESCE(NULLIF(CURRENT_SETTING('pghistory.context_metadata', TRUE), ''),"
+                    " NULL)::JSONB"
+                )
+            else:
+                raise AssertionError
+
+        if hasattr(self.event_model, "pgh_context_id") and isinstance(
+            self.event_model._meta.get_field("pgh_context_id"), models.UUIDField
+        ):
+            fields[
+                "pgh_context_id"
+            ] = "COALESCE(NULLIF(CURRENT_SETTING('pghistory.context_id', TRUE), ''), NULL)::UUID"
+
+        fields = {key: fields[key] for key in sorted(fields)}
 
         cols = ", ".join(f'"{col}"' for col in fields)
         vals = ", ".join(val for val in fields.values())
